---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2006-04-04;159
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20060429&codiceRedaz=006G0180&dataVigenza=20251104
dataGU: 20060429
codiceRedaz: 006G0180
dataVigenza: 20251104
---

# Disposizioni integrative e correttive al decreto legislativo 7 marzo 2005, n. 82, recante codice dell'amministrazione digitale.

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76, 87 e 117, secondo comma, lettera r), della Costituzione;

Visto l'articolo 14 della legge 23 agosto 1988, n. 400, recante disciplina dell'attivita' di Governo e ordinamento della Presidenza del Consiglio dei Ministri;

Visto l'articolo 10 della legge 29 luglio 2003, n. 229, recante interventi in materia di qualita' della regolazione, riassetto normativo e codificazione - Legge di semplificazione 2001;

Vista la legge 7 agosto 1990, n. 241, recante nuove norme in materia di procedimento amministrativo e di diritto di accesso ai documenti amministrativi;

Visto il decreto legislativo 12 febbraio 1993, n. 39, recante norme in materia di sistemi informativi automatizzati delle amministrazioni pubbliche, a norma dell'articolo 2, comma 1, lettera mm), della legge 23 ottobre 1992, n. 421;

Visto il decreto legislativo 30 luglio 1999, n. 300, recante disciplina dell'attivita' di Governo e ordinamento della Presidenza del Consiglio dei Ministri;

Visto il testo unico delle disposizioni legislative e regolamentari in materia di documentazione amministrativa (Testo A), di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445;

Visto il decreto legislativo 30 marzo 2001, n. 165, recante norme generali sull'ordinamento del lavoro alle dipendenze delle amministrazioni pubbliche;

Visto il decreto legislativo 30 giugno 2003, n. 196, recante codice in materia di protezione dei dati personali;

Vista la legge 9 gennaio 2004, n. 4, recante disposizioni per favorire l'accesso dei soggetti disabili agli strumenti informatici;

Visto il decreto legislativo 7 marzo 2005, n. 82, recante codice dell'amministrazione digitale;

Visto il decreto legislativo 28 febbraio 2005, n. 42, recante istituzione del sistema pubblico di connettivita' e la rete internazionale della pubblica amministrazione, a norma dell'articolo 10 della legge 23 luglio 2003, n. 229;

Visto il decreto del Presidente del Consiglio dei Ministri del 6 maggio 2005, recante «Delega di funzioni in materia di innovazione e tecnologie» al Ministro senza portafoglio dott. Lucio Stanca;

Vista la preliminare deliberazione del Consiglio dei Ministri, adottata nella riunione del 2 dicembre 2005;

Esperita la procedura di notifica alla Commissione europea di cui alla direttiva 98/34/CE del Parlamento europeo e del Consiglio, del 22 giugno 1998, modificata dalla direttiva 98/48/CE del Parlamento europeo e del Consiglio, del 20 luglio 1998, attuata dalla legge 21 giugno 1986, n. 317, cosi' come modificata dal decreto legislativo 23 novembre 2000, n. 427;

Acquisito il parere della Conferenza unificata, ai sensi dell'articolo 8, del decreto legislativo 28 agosto 1997, n. 281, espresso nella riunione del 26 gennaio 2006;

Sentito il Garante per la protezione dei dati personali;

Udito il parere del Consiglio di Stato, espresso dalla Sezione consultiva per gli atti normativi nell'adunanza del 30 gennaio 2006;

Acquisito il parere delle competenti Commissioni della Camera dei deputati e del Senato della Repubblica;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 17 marzo 2006;

Sulla proposta del Ministro per l'innovazione e le tecnologie, di concerto con il Ministro per la funzione pubblica, con il Ministro dell'economia e delle finanze, con il Ministro dell'interno, con il Ministro della giustizia, con il Ministro delle attivita' produttive e con il Ministro delle comunicazioni;

Emana il seguente decreto legislativo:

## Art. 1. - Modifica all'articolo 1 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 1 dell'articolo 1 del decreto legislativo 7 marzo 2005, n. 82, di seguito denominato: «decreto legislativo», sono apportate le seguenti modificazioni: alla lettera b) dopo le parole: «opportune tecnologie» e' aggiunta la seguente: «anche»; alla lettera e) dopo le parole: «che collegano» sono inserite le seguenti: «all'identita' del titolare» e sono soppresse le parole: «ai titolari e confermano l'identita' informatica dei titolari stessi;»; alla lettera q) la parola: «autenticazione» e' sostituita dalla seguente: «identificazione»; alla lettera r) sono soppresse le parole: «e la sua univoca autenticazione informatica», nonche' le parole: «, quale l'apparato strumentale usato per la creazione della firma elettronica».

## Art. 2. - Modifica all'articolo 2 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 5 dell'articolo 2 del decreto legislativo, dopo le parole: «delle disposizioni» sono inserite le seguenti: «del codice»; al termine e' aggiunto il seguente periodo: «I cittadini e le imprese hanno, comunque, diritto ad ottenere che il trattamento dei dati effettuato mediante l'uso di tecnologie telematiche sia conformato al rispetto dei diritti e delle liberta' fondamentali, nonche' della dignita' dell'interessato.».

## Art. 3. - Modifica all'articolo 3 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 1 dell'articolo 3 del decreto legislativo dopo le parole: «pubbliche amministrazioni» e' soppressa la parola: «centrali».

2. Dopo il comma 1 dell'articolo 3 del decreto legislativo sono inseriti i seguenti: «1-bis. Il principio di cui al comma 1 si applica alle amministrazioni regionali e locali nei limiti delle risorse tecnologiche ed organizzative disponibili e nel rispetto della loro autonomia normativa. 1-ter. Le controversie concernenti l'esercizio del diritto di cui al comma 1 sono devolute alla giurisdizione esclusiva del giudice amministrativo.».

## Art. 4. - Modifica all'articolo 10 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 4 dell'articolo 10 del decreto legislativo le parole: «al decreto legislativo 28 febbraio 2005, n. 42» sono sostituite dalle seguenti: «al presente decreto,».

## Art. 5. - Modifica all'articolo 12 del decreto legislativo 7 marzo 2005, n. 82

1. Dopo il comma 1 dell'articolo 12 del decreto legislativo, sono inseriti i seguenti: «1-bis. Gli organi di governo nell'esercizio delle funzioni di indirizzo politico ed in particolare nell'emanazione delle direttive generali per l'attivita' amministrativa e per la gestione ai sensi del comma 1 dell'articolo 14 del decreto legislativo n. 165 del 2001, promuovono l'attuazione delle disposizioni del presente decreto. 1-ter. I dirigenti rispondono dell'osservanza ed attuazione delle disposizioni di cui al presente decreto ai sensi e nei limiti degli articoli 21 e 55 del decreto legislativo 30 marzo 2001, n. 165, ferme restando le eventuali responsabilita' penali, civili e contabili previste dalle norme vigenti.».

2. Dopo il comma 5 dell'articolo 12 e' aggiunto il seguente: «5-bis. Le pubbliche amministrazioni implementano e consolidano i processi di informatizzazione in atto, ivi compresi quelli riguardanti l'erogazione in via telematica di servizi a cittadini ed imprese anche con l'intervento di privati.».

## Art. 6. - Modifica all'articolo 14 del decreto legislativo 7 marzo 2005, n. 82

1. Dopo il comma 3 dell'articolo 14 del decreto legislativo e' inserito il seguente: «3-bis. Ai fini di quanto previsto ai commi 1, 2 e 3, e' istituita senza nuovi o maggiori oneri per la finanza pubblica, presso la Conferenza unificata, previa delibera della medesima che ne definisce la composizione e le specifiche competenze, una Commissione permanente per l'innovazione tecnologica nelle regioni e negli enti locali con funzioni istruttorie e consultive.».

## Art. 7. - Modifica all'articolo 17 del decreto legislativo 7 marzo 2005, n. 82

1. Dopo il comma 1 dell'articolo 17 del decreto legislativo e' inserito il seguente: «1-bis. Ciascun Ministero istituisce un unico centro di competenza, salva la facolta' delle Agenzie di istituire un proprio centro.».

## Art. 8. - Modifica all'articolo 20 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 1 dell'articolo 20 del decreto legislativo, dopo le parole: «con strumenti telematici» sono inserite le seguenti: «conformi alle regole tecniche di cui all'articolo 71»; le parole da: «a tutti gli effetti di legge, se conformi alle disposizioni del presente codice ed alle regole tecniche di cui all'articolo 71» sono sostituite dalle seguenti: «agli effetti di legge, ai sensi delle disposizioni del presente codice».

2. Dopo il comma 1 dell'articolo 20 del decreto legislativo, e' inserito il seguente: «1-bis. L'idoneita' del documento informatico a soddisfare il requisito della forma scritta e' liberamente valutabile in giudizio, tenuto conto delle sue caratteristiche oggettive di qualita', sicurezza, integrita' ed immodificabilita', fermo restando quanto disposto dal comma 2.».

3. Il comma 2 dell'articolo 20 del decreto legislativo e' sostituito dal seguente: «2. Il documento informatico sottoscritto con firma elettronica qualificata o con firma digitale, formato nel rispetto delle regole tecniche stabilite ai sensi dell'articolo 71, che garantiscano l'identificabilita' dell'autore, l'integrita' e l'immodificabilita' del documento, si presume riconducibile al titolare del dispositivo di firma ai sensi dell'articolo 21, comma 2, e soddisfa comunque il requisito della forma scritta, anche nei casi previsti, sotto pena di nullita', dall'articolo 1350, primo comma, numeri da 1 a 12 del codice civile.».

4. Al comma 3 dell'articolo 20 del decreto legislativo dopo le parole: «Le regole tecniche» sono inserite le seguenti : «per la formazione,».

## Art. 9. - Modifica all'articolo 21 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 1 dell'articolo 21 del decreto legislativo, le parole: «e sicurezza» sono sostituite dalle seguenti: «, sicurezza, integrita' e immodificabilita».

2. Al comma 2 dell'articolo 21 del decreto legislativo il periodo: «L'utilizzo del dispositivo di firma si presume riconducibile al titolare, salvo che sia data prova contraria.» e' sostituito dal seguente: «L'utilizzo del dispositivo di firma si presume riconducibile al titolare, salvo che questi dia prova contraria.».

## Art. 10. - Modifica della rubrica dell'articolo 22 del decreto legislativo 7 marzo 2005, n. 82

1. La rubrica dell'articolo 22 del decreto legislativo e' sostituita dalla seguente: «Documenti informatici originali e copie. Formazione e conservazione.».

## Art. 11. - Modifica all'articolo 23 del decreto legislativo 7 marzo 2005, n. 82, ed all'articolo 1, comma 51, della legge 23 dicembre 2005, n. 266

1. Dopo il comma 2 dell'articolo 23 del decreto legislativo e' inserito il seguente: «2-bis. Le copie su supporto cartaceo di documento informatico, anche sottoscritto con firma elettronica qualificata o con firma digitale, sostituiscono ad ogni effetto di legge l'originale da cui sono tratte se la loro conformita' all'originale in tutte le sue componenti e' attestata da un pubblico ufficiale a cio' autorizzato.».

2. All'articolo 1, comma 51 della legge 23 dicembre 2005, n. 266, nel terzo periodo, dopo le parole: «vigenti regole tecniche,» e' soppressa la parola: «anche»; al quarto periodo dopo le parole: «su supporto cartaceo» sono inserite le seguenti: «dei documenti di cui al presente comma».

## Art. 12. - Modifiche all'articolo 28 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 1, lettera g), dell'articolo 28 del decreto legislativo, la parola: «qualificata» e' soppressa e dopo le parole: «rilasciato il certificato» sono aggiunte le seguenti: «, realizzata in conformita' alle regole tecniche ed idonea a garantire l'integrita' e la veridicita' di tutte le informazioni contenute nel certificato medesimo».

2. Al comma 3 dell'articolo 28 del decreto legislativo, le parole: «Il certificato qualificato contiene», sono sostituite dalle seguenti: «Il certificato qualificato puo' contenere».

3. Alla lettera a) del comma 3 dell'articolo 28 del decreto legislativo, dopo le parole: «o collegi professionali,» sono inserite le seguenti: «la qualifica di pubblico ufficiale,».

4. La lettera b) del comma 3 dell'articolo 28 del decreto legislativo, e' sostituita dalla seguente: «b) i limiti d'uso del certificato, inclusi quelli derivanti dalla titolarita' delle qualifiche e dai poteri di rappresentanza di cui alla lettera a) ai sensi dell'articolo 30, comma 3.».

## Art. 13. - Modifiche all'articolo 30 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 3 dell'articolo 30 del decreto legislativo le parole: «nel processo di verifica della firma» sono sostituite dalle seguenti: «nel certificato».

## Art. 14. - Modifiche all'articolo 32 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 1 dell'articolo 32 del decreto legislativo dopo le parole: «Il titolare del certificato di firma e' tenuto» sono inserite le seguenti: «ad assicurare la custodia del dispositivo di firma e»; dopo le parole «tecniche idonee ad evitare danno ad altri» sono inserite le seguenti: «; e' altresi' tenuto ad utilizzare personalmente il dispositivo di firma.»; sono soppresse le parole: «ed a custodire e utilizzare il dispositivo di firma con la diligenza del buon padre di famiglia.».

2. Al comma 2 dell'articolo 32 del decreto legislativo, le parole: «ad altri, ivi incluso il titolare del certificato» sono sostituite dalle seguenti: «a terzi».

3. Alla lettera j) del comma 3 dell'articolo 32 del decreto legislativo le parole: «dieci anni» sono sostituite dalle seguenti: «venti anni».

## Art. 15. - Modifiche all'articolo 34 del decreto legislativo 7 marzo 2005, n. 82

1. Alla lettera a) del comma 1 dell'articolo 34 del decreto legislativo dopo le parole: «sono privi di ogni effetto» sono aggiunte le seguenti: «ad esclusione di quelli rilasciati da collegi e ordini professionali e relativi organi agli iscritti nei rispettivi albi e registri».

2. Al comma 2 dell'articolo 34 del decreto legislativo le parole: «all'articolo 72» sono sostituite dalle seguenti: «all'articolo 71».

## Art. 16. - Modifiche all'articolo 36 del decreto legislativo 7 marzo 2005, n. 82

1. Alla lettera a) del comma 1 dell'articolo 36 del decreto legislativo dopo le parole: «dal comma 2» sono inserite le seguenti: «dell'articolo 37».

## Art. 17. - Modifiche alla Sezione III del decreto legislativo 7 marzo 2005, n. 82

1. Dopo l'articolo 37 del decreto legislativo le parole: «Sezione III - Contratti, pagamenti, libri e scritture» sono sostituite dalle seguenti: «Sezione III - Pagamenti, libri e scritture».

## Art. 18. - Modifiche all'articolo 41 del decreto legislativo 7 marzo 2005, n. 82

1. Dopo il comma 2 dell'articolo 41, del decreto legislativo sono inseriti i seguenti: «2-bis. Il fascicolo informatico e' realizzato garantendo la possibilita' di essere direttamente consultato ed alimentato da tutte le amministrazioni coinvolte nel procedimento. Le regole per la costituzione e l'utilizzo del fascicolo sono conformi ai principi di una corretta gestione documentale ed alla disciplina della formazione, gestione, conservazione e trasmissione del documento informatico, ivi comprese le regole concernenti il protocollo informatico ed il sistema pubblico di connettivita', e comunque rispettano i criteri dell'interoperabilita' e della cooperazione applicativa; regole tecniche specifiche possono essere dettate ai sensi dell'articolo 71, di concerto con il Ministro della funzione pubblica. 2-ter. Il fascicolo informatico reca l'indicazione: a) dell'amministrazione titolare del procedimento, che cura la costituzione e la gestione del fascicolo medesimo; b) delle altre amministrazioni partecipanti; c) del responsabile del procedimento; d) dell'oggetto del procedimento; e) dell'elenco dei documenti contenuti, salvo quanto disposto dal comma 2-quater. 2-quater. Il fascicolo informatico puo' contenere aree a cui hanno accesso solo l'amministrazione titolare e gli altri soggetti da essa individuati; esso e' formato in modo da garantire la corretta collocazione, la facile reperibilita' e la collegabilita', in relazione al contenuto ed alle finalita', dei singoli documenti; e' inoltre costituito in modo da garantire l'esercizio in via telematica dei diritti previsti dalla citata legge n. 241 del 1990.».

## Art. 19. - Modifiche all'articolo 47 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 3 dell'articolo 47, del decreto legislativo 7 marzo 2005, n. 82, le parole: «Entro ventiquattro mesi» sono sostituite dalle seguenti: «Entro otto mesi».

## Art. 20. - Modifica all'articolo 50 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 3 dell'articolo 50 del decreto legislativo le parole: «di cui al decreto legislativo 28 febbraio 2005, n. 42» sono sostituite dalle seguenti: «di cui al presente decreto».

## Art. 21. - Modifiche all'articolo 53 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 1 dell'articolo 53 del decreto legislativo e' aggiunto, in fine, il seguente periodo: «Sono in particolare resi facilmente reperibili e consultabili i dati di cui all'articolo 54.».

## Art. 22. - Modifiche all'articolo 54 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 1 dell'articolo 54 del decreto legislativo dopo le parole: «I siti delle pubbliche amministrazioni» la parola: «centrali» e' soppressa e alla lettera a) dopo le parole: «di livello dirigenziale non generale,» sono aggiunte le seguenti: «i nomi dei dirigenti responsabili dei singoli uffici,».

2. Al comma 2 dell'articolo 54, del decreto legislativo dopo le parole: «Le amministrazioni» sono inserite le seguenti: «centrali».

3. Dopo il comma 2 dell'articolo 54 del decreto legislativo e' inserito il seguente: «2-bis. Il principio di cui al comma 1 si applica alle amministrazioni regionali e locali nei limiti delle risorse tecnologiche e organizzative disponibili e nel rispetto della loro autonomia normativa.».

4. Dopo il comma 4 dell'articolo 54 del decreto legislativo e' aggiunto il seguente: «4-bis. La pubblicazione telematica produce effetti di pubblicita' legale nei casi e nei modi espressamente previsti dall'ordinamento.».

## Art. 23. - Modifica all'articolo 56 del decreto legislativo 7 marzo 2005, n. 82

1. Alla rubrica dell'articolo 56, del decreto legislativo le parole: «al giudice amministrativo e contabile» sono sostituite dalle seguenti: «autorita' giudiziaria di ogni ordine e grado».

2. Dopo il comma 2 dell'articolo 56, del decreto legislativo e' aggiunto il seguente: «2-bis. I dati identificativi delle questioni pendenti, le sentenze e le altre decisioni depositate in cancelleria o segreteria dell'autorita' giudiziaria di ogni ordine e grado sono, comunque, rese accessibili ai sensi dell'articolo 51 del codice in materia di protezione dei dati personali approvato con decreto legislativo n. 196 del 2003.».

## Art. 24. - Modifica all'articolo 58 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 3 dell'articolo 58 del decreto legislativo dopo le parole: «Il CNIPA» sono inserite le seguenti: «, sentito il Garante per la protezione dei dati personali,».

## Art. 25. - Modifica all'articolo 59 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 2 dell'articolo 59 del decreto legislativo le parole: «in coerenza con le disposizioni del sistema pubblico di connettivita' di cui al decreto legislativo 28 febbraio 2005, n. 42», sono sostituite dalle seguenti: «in coerenza con le disposizioni del presente decreto che disciplinano il sistema pubblico di connettivita'.».

2. Dopo il comma 7 dell'articolo 59, del decreto legislativo e' inserito il seguente: «7-bis. Nell'ambito dei dati territoriali di interesse nazionale rientra la base dei dati catastali gestita dall'Agenzia del territorio. Per garantire la circolazione e la fruizione dei dati catastali conformemente alle finalita' ed alle condizioni stabilite dall'articolo 50, il direttore dell'Agenzia del territorio, di concerto con il Comitato per le regole tecniche sui dati territoriali delle pubbliche amministrazioni e previa intesa con la Conferenza unificata, definisce con proprio decreto entro la data del 30 giugno 2006, in coerenza con le disposizioni che disciplinano il sistema pubblico di connettivita', le regole tecnico economiche per l'utilizzo dei dati catastali per via telematica da parte dei sistemi informatici di altre amministrazioni.».

## Art. 26. - Modifiche all'articolo 62 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 1 dell'articolo 62 del decreto legislativo dopo le parole: «e' realizzato con strumenti informatici» sono aggiunte le seguenti: «e nel rispetto delle regole tecniche concernenti il sistema pubblico di connettivita', in coerenza con le quali il Ministero dell'interno definisce le regole di sicurezza per l'accesso e per la gestione delle informazioni anagrafiche e fornisce i servizi di convalida delle informazioni medesime ove richiesto per l'attuazione della normativa vigente».

## Art. 27. - Modifica all'articolo 64 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 3 dell'articolo 64 del decreto legislativo e' aggiunto, infine, il seguente periodo: «E' prorogato alla medesima data il termine relativo alla procedura di accertamento preventivo del possesso della Carta di identita' elettronica (CIE), di cui all'articolo 8, comma 5, del decreto del Presidente della Repubblica 2 marzo 2004, n. 117, limitatamente alle richieste di emissione di Carte nazionali dei servizi (CNS) da parte dei cittadini non residenti nei comuni in cui e' diffusa la CIE.».

## Art. 28. - Modifiche all'articolo 65 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 2 dell'articolo 65 del decreto legislativo dopo le parole: «Le istanze e le dichiarazioni inviate» sono inserite le seguenti: «o compilate su sito»; dopo le parole: «addetto al procedimento» sono aggiunte le seguenti: «; resta salva la facolta' della pubblica amministrazione di stabilire i casi in cui e' necessaria la sottoscrizione mediante la firma digitale».

## Art. 29. - Modifica all'articolo 71 del decreto legislativo 7 marzo 2005, n. 82

1. Al comma 1 dell'articolo 71 del decreto legislativo le parole: «di cui all'articolo 16 del decreto legislativo 28 febbraio 2005, n. 42.» sono soppresse e dopo le parole: «nelle materie di competenza,» sono inserite le seguenti: «previa acquisizione obbligatoria del parere tecnico del CNIPA».

2. Dopo il comma 1 dell'articolo 71 del decreto legislativo, sono inseriti i seguenti: «1-bis. Entro nove mesi dalla data di entrata in vigore del presente decreto, con uno o piu' decreti del Presidente del Consiglio dei Ministri emanati su proposta del Ministro delegato per l'innovazione e le tecnologie, sentito il Ministro per la funzione pubblica, d'intesa con la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, sono adottate le regole tecniche e di sicurezza per il funzionamento del sistema pubblico di connettivita'.». «1-ter. Le regole tecniche di cui al presente codice sono dettate in conformita' alle discipline risultanti dal processo di standardizzazione tecnologica a livello internazionale ed alle normative dell'Unione europea.».

## Art. 30. - Introduzione del Capo VIII del decreto legislativo 7 marzo 2005, n. 82

1. Dopo il capo VII del decreto legislativo e' introdotto il seguente: «CAPO VIII Sistema pubblico di connettivita' e rete internazionale della pubblica amministrazione SEZIONE I Definizioni relative al sistema pubblico di connettivita' Art. 72. Definizioni relative al sistema pubblico di connettivita' 1. Ai fini del presente decreto si intende per: a) "trasporto di dati": i servizi per la realizzazione, gestione ed evoluzione di reti informatiche per la trasmissione di dati, oggetti multimediali e fonia; b) "interoperabilita' di base": i servizi per la realizzazione, gestione ed evoluzione di strumenti per lo scambio di documenti informatici fra le pubbliche amministrazioni e tra queste e i cittadini; c) "connettivita'": l'insieme dei servizi di trasporto di dati e di interoperabilita' di base; d) "interoperabilita' evoluta": i servizi idonei a favorire la circolazione, lo scambio di dati e informazioni, e l'erogazione fra le pubbliche amministrazioni e tra queste e i cittadini; e) "cooperazione applicativa": la parte del sistema pubblico di connettivita' finalizzata all'interazione tra i sistemi informatici delle pubbliche amministrazioni per garantire l'integrazione dei metadati, delle informazioni e dei procedimenti amministrativi. Art. 73. Sistema pubblico di connettivita' (SPC) 1. Nel rispetto dell'articolo 117, secondo comma, lettera r), della Costituzione, e nel rispetto dell'autonomia dell'organizzazione interna delle funzioni informative delle regioni e delle autonomie locali il presente Capo definisce e disciplina il Sistema pubblico di connettivita' (SPC), al fine di assicurare il coordinamento informativo e informatico dei dati tra le amministrazioni centrali, regionali e locali e promuovere l'omogeneita' nella elaborazione e trasmissione dei dati stessi, finalizzata allo scambio e diffusione delle informazioni tra le pubbliche amministrazioni e alla realizzazione di servizi integrati. 2. Il SPC e' l'insieme di infrastrutture tecnologiche e di regole tecniche, per lo sviluppo, la condivisione, l'integrazione e la diffusione del patrimonio informativo e dei dati della pubblica amministrazione, necessarie per assicurare l'interoperabilita' di base ed evoluta e la cooperazione applicativa dei sistemi informatici e dei flussi informativi, garantendo la sicurezza, la riservatezza delle informazioni, nonche' la salvaguardia e l'autonomia del patrimonio informativo di ciascuna pubblica amministrazione. 3. La realizzazione del SPC avviene nel rispetto dei seguenti principi: a) sviluppo architetturale ed organizzativo atto a garantire la natura federata, policentrica e non gerarchica del sistema; b) economicita' nell'utilizzo dei servizi di rete, di interoperabilita' e di supporto alla cooperazione applicativa; c) sviluppo del mercato e della concorrenza nel settore delle tecnologie dell'informazione e della comunicazione. Art. 74. Rete internazionale delle pubbliche amministrazioni 1. Il presente decreto definisce e disciplina la Rete internazionale delle pubbliche amministrazioni, interconnessa al SPC. La Rete costituisce l'infrastruttura di connettivita' che collega, nel rispetto della normativa vigente, le pubbliche amministrazioni con gli uffici italiani all'estero, garantendo adeguati livelli di sicurezza e qualita'. SEZIONE II Sistema pubblico di connettivita' SPC Art. 75. Partecipazione al Sistema pubblico di connettivita' 1. Al SPC partecipano tutte le amministrazioni di cui all'articolo 2, comma 2. 2. Il comma 1 non si applica alle amministrazioni di cui al decreto legislativo 30 marzo 2001, n. 165, limitatamente all'esercizio delle sole funzioni di ordine e sicurezza pubblica, difesa nazionale, consultazioni elettorali. 3. Ai sensi dell'articolo 3 del decreto del Presidente della Repubblica 11 novembre 1994, n. 680, nonche' dell'articolo 25 del decreto legislativo 30 giugno 2003, n. 196, e' comunque garantita la connessione con il SPC dei sistemi informativi degli organismi competenti per l'esercizio delle funzioni di sicurezza e difesa nazionale, nel loro esclusivo interesse e secondo regole tecniche che assicurino riservatezza e sicurezza. E' altresi' garantita la possibilita' di connessione al SPC delle autorita' amministrative indipendenti. Art. 76. Scambio di documenti informatici nell'ambito del Sistema pubblico di connettivita' 1. Gli scambi di documenti informatici tra le pubbliche amministrazioni nell'ambito del SPC, realizzati attraverso la cooperazione applicativa e nel rispetto delle relative procedure e regole tecniche di sicurezza, costituiscono invio documentale valido ad ogni effetto di legge. Art. 77. Finalita' del Sistema pubblico di connettivita' 1. Al SPC sono attribuite le seguenti finalita': a) fornire un insieme di servizi di connettivita' condivisi dalle pubbliche amministrazioni interconnesse, definiti negli aspetti di funzionalita', qualita' e sicurezza, ampiamente graduabili in modo da poter soddisfare le differenti esigenze delle pubbliche amministrazioni aderenti al SPC; b) garantire l'interazione della pubblica amministrazione centrale e locale con tutti gli altri soggetti connessi a Internet, nonche' con le reti di altri enti, promuovendo l'erogazione di servizi di qualita' e la miglior fruibilita' degli stessi da parte dei cittadini e delle imprese; c) fornire un'infrastruttura condivisa di interscambio che consenta l'interoperabilita' tra tutte le reti delle pubbliche amministrazioni esistenti, favorendone lo sviluppo omogeneo su tutto il territorio nella salvaguardia degli investimenti effettuati; d) fornire servizi di connettivita' e cooperazione alle pubbliche amministrazioni che ne facciano richiesta, per permettere l'interconnessione delle proprie sedi e realizzare cosi' anche l'infrastruttura interna di comunicazione; e) realizzare un modello di fornitura dei servizi multifornitore coerente con l'attuale situazione di mercato e le dimensioni del progetto stesso; f) garantire lo sviluppo dei sistemi informatici nell'ambito del SPC salvaguardando la sicurezza dei dati, la riservatezza delle informazioni, nel rispetto dell'autonomia del patrimonio informativo delle singole amministrazioni e delle vigenti disposizioni in materia di protezione dei dati personali. Art. 78. Compiti delle pubbliche amministrazioni nel Sistema pubblico di connettivita' 1. Le pubbliche amministrazioni nell'ambito della loro autonomia funzionale e gestionale adottano nella progettazione e gestione dei propri sistemi informativi, ivi inclusi gli aspetti organizzativi, soluzioni tecniche compatibili con la cooperazione applicativa con le altre pubbliche amministrazioni, secondo le regole tecniche di cui all'articolo 71, comma 1-bis. 2. Per le amministrazioni di cui all'articolo 1, comma 1, del decreto legislativo 12 febbraio 1993, n. 39, le responsabilita' di cui al comma 1 sono attribuite al dirigente responsabile dei sistemi informativi automatizzati, di cui all'articolo 10, comma 1, dello stesso decreto legislativo. Art. 79. Commissione di coordinamento del Sistema pubblico di connettivita' 1. E' istituita la Commissione di coordinamento del SPC, di seguito denominata: «Commissione», preposta agli indirizzi strategici del SPC. 2. La Commissione: a) assicura il raccordo tra le amministrazioni pubbliche, nel rispetto delle funzioni e dei compiti spettanti a ciascuna di esse; b) approva le linee guida, le modalita' operative e di funzionamento dei servizi e delle procedure per realizzare la cooperazione applicativa fra i servizi erogati dalle amministrazioni; c) promuove l'evoluzione del modello organizzativo e dell'architettura tecnologica del SPC in funzione del mutamento delle esigenze delle pubbliche amministrazioni e delle opportunita' derivanti dalla evoluzione delle tecnologie; d) promuove la cooperazione applicativa fra le pubbliche amministrazioni, nel rispetto delle regole tecniche di cui all'articolo 71; e) definisce i criteri e ne verifica l'applicazione in merito alla iscrizione, sospensione e cancellazione dagli elenchi dei fornitori qualificati SPC di cui all'articolo 82; f) dispone la sospensione e cancellazione dagli elenchi dei fornitori qualificati di cui all'articolo 82; g) verifica la qualita' e la sicurezza dei servizi erogati dai fornitori qualificati del SPC; h) promuove il recepimento degli standard necessari a garantire la connettivita', l'interoperabilita' di base e avanzata, la cooperazione applicativa e la sicurezza del Sistema. 3. Le decisioni della Commissione sono assunte a maggioranza semplice o qualificata dei componenti in relazione all'argomento in esame. La Commissione a tale fine elabora, entro tre mesi dal suo insediamento, un regolamento interno da approvare con maggioranza qualificata dei suoi componenti. Art. 80. Composizione della Commissione di coordinamento del sistema pubblico di connettivita' 1. La Commissione e' formata da diciassette componenti incluso il Presidente di cui al comma 2, scelti tra persone di comprovata professionalita' ed esperienza nel settore, nominati con decreto del Presidente del Consiglio dei Ministri: otto componenti sono nominati in rappresentanza delle amministrazioni statali previa deliberazione del Consiglio dei Ministri, sette dei quali su proposta del Ministro per l'innovazione e le tecnologie ed uno su proposta del Ministro per la funzione pubblica; i restanti otto sono nominati su designazione della Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281. Uno dei sette componenti proposti dal Ministro per l'innovazione e le tecnologie e' nominato in rappresentanza della Presidenza del Consiglio dei Ministri. Quando esamina questioni di interesse della rete internazionale della pubblica amministrazione la Commissione e' integrata da un rappresentante del Ministero degli affari esteri, qualora non ne faccia gia' parte. 2. Il Presidente del Centro nazionale per l'informatica nella pubblica amministrazione e' componente di diritto e presiede la Commissione. Gli altri componenti della Commissione restano in carica per un biennio e l'incarico e' rinnovabile. 3. La Commissione e' convocata dal Presidente e si riunisce almeno quattro volte l'anno. 4. L'incarico di Presidente o di componente della Commissione e la partecipazione alle riunioni della Commissione non danno luogo alla corresponsione di alcuna indennita', emolumento, compenso e rimborso spese e le amministrazioni interessate provvedono agli oneri di missione nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente, senza nuovi o maggiori oneri per la finanza pubblica. 5. Per i necessari compiti istruttori la Commissione si avvale del Centro nazionale per l'informatica nella pubblica amministrazione, di seguito denominato: «CNIPA» e sulla base di specifiche convenzioni, di organismi interregionali e territoriali. 6. La Commissione puo' avvalersi, nell'ambito delle risorse umane, finanziarie e strumentali disponibili a legislazione vigente, senza nuovi o maggiori oneri per la finanza pubblica, della consulenza di uno o piu' organismi di consultazione e cooperazione istituiti con appositi accordi ai sensi dell'articolo 9, comma 2, lettera c), del decreto legislativo 28 agosto 1997, n. 281. 7. Ai fini della definizione degli sviluppi strategici del SPC, in relazione all'evoluzione delle tecnologie dell'informatica e della comunicazione, la Commissione puo' avvalersi, nell'ambito delle risorse finanziarie assegnate al CNIPA a legislazione vigente e senza nuovi o maggiori oneri per la finanza pubblica, di consulenti di chiara fama ed esperienza in numero non superiore a cinque secondo le modalita' definite nei regolamenti di cui all'articolo 87. Art. 81. Ruolo del Centro nazionale per l'informatica nella pubblica amministrazione 1. Il CNIPA, nel rispetto delle decisioni e degli indirizzi forniti dalla Commissione, anche avvalendosi di soggetti terzi, gestisce le risorse condivise del SPC e le strutture operative preposte al controllo e supervisione delle stesse, per tutte le pubbliche amministrazioni di cui all'articolo 2, comma 2. 2. Il CNIPA, anche avvalendosi di soggetti terzi, cura la progettazione, la realizzazione, la gestione e l'evoluzione del SPC per le amministrazioni di cui all'articolo 1, comma 1, del decreto legislativo 12 febbraio 1993, n. 39. Art. 82. Fornitori del Sistema pubblico di connettivita' 1. Sono istituiti uno o piu' elenchi di fornitori a livello nazionale e regionale in attuazione delle finalita' di cui all'articolo 77. 2. I fornitori che ottengono la qualificazione SPC ai sensi dei regolamenti previsti dall'articolo 87, sono inseriti negli elenchi di competenza nazionale o regionale, consultabili in via telematica, esclusivamente ai fini dell'applicazione della disciplina di cui al presente decreto, e tenuti rispettivamente dal CNIPA a livello nazionale e dalla regione di competenza a livello regionale. I fornitori in possesso dei suddetti requisiti sono denominati fornitori qualificati SPC. 3. I servizi per i quali e' istituito un elenco, ai sensi del comma 1, sono erogati, nell'ambito del SPC, esclusivamente dai soggetti che abbiano ottenuto l'iscrizione nell'elenco di competenza nazionale o regionale. 4. Per l'iscrizione negli elenchi dei fornitori qualificati SPC e' necessario che il fornitore soddisfi almeno i seguenti requisiti: a) disponibilita' di adeguate infrastrutture e servizi di comunicazioni elettroniche; b) esperienza comprovata nell'ambito della realizzazione gestione ed evoluzione delle soluzioni di sicurezza informatica; c) possesso di adeguata rete commerciale e di assistenza tecnica; d) possesso di adeguati requisiti finanziari e patrimoniali, anche dimostrabili per il tramite di garanzie rilasciate da terzi qualificati. 5. Limitatamente ai fornitori dei servizi di connettivita' dovranno inoltre essere soddisfatti anche i seguenti requisiti: a) possesso dei necessari titoli abilitativi di cui al decreto legislativo 1° agosto 2003, n. 259, per l'ambito territoriale di esercizio dell'attivita'; b) possesso di comprovate conoscenze ed esperienze tecniche nella gestione delle reti e servizi di comunicazioni elettroniche, anche sotto il profilo della sicurezza e della protezione dei dati. Art. 83. Contratti quadro 1. Al fine della realizzazione del SPC, il CNIPA a livello nazionale e le regioni nell'ambito del proprio territorio, per soddisfare esigenze di coordinamento, qualificata competenza e indipendenza di giudizio, nonche' per garantire la fruizione, da parte delle pubbliche amministrazioni, di elevati livelli di disponibilita' dei servizi e delle stesse condizioni contrattuali proposte dal miglior offerente, nonche' una maggiore affidabilita' complessiva del sistema, promuovendo, altresi', lo sviluppo della concorrenza e assicurando la presenza di piu' fornitori qualificati, stipulano, espletando specifiche procedure ad evidenza pubblica per la selezione dei contraenti, nel rispetto delle vigenti norme in materia, uno o piu' contratti-quadro con piu' fornitori per i servizi di cui all'articolo 77, con cui i fornitori si impegnano a contrarre con le singole amministrazioni alle condizioni ivi stabilite. 2. Le amministrazioni di cui all'articolo 1, comma 1, del decreto legislativo 12 febbraio 1993, n. 39, sono tenute a stipulare gli atti esecutivi dei contratti-quadro con uno o piu' fornitori di cui al comma 1, individuati dal CNIPA. Gli atti esecutivi non sono soggetti al parere del CNIPA e, ove previsto, del Consiglio di Stato. Le amministrazioni non ricomprese tra quelle di cui al citato art. 1, comma 1, del decreto legislativo n. 39 del 1993, hanno facolta' di stipulare gli atti esecutivi di cui al presente articolo. Art. 84. Migrazione della Rete unitaria della pubblica amministrazione 1. Le Amministrazioni di cui all'articolo 1, comma 1, del decreto legislativo 12 febbraio 1993, n. 39, aderenti alla Rete unitaria della pubblica amministrazione, presentano al CNIPA, secondo le indicazioni da esso fornite, i piani di migrazione verso il SPC, da attuarsi entro diciotto mesi dalla data di approvazione del primo contratto quadro di cui all'articolo 83, comma 1, termine di cessazione dell'operativita' della Rete unitaria della pubblica amministrazione. 2. Dalla data di entrata in vigore del presente articolo ogni riferimento normativo alla Rete unitaria della pubblica amministrazione si intende effettuato al SPC. SEZIONE III Rete internazionale della pubblica amministrazione e compiti del CNIPA Art. 85. Collegamenti operanti per il tramite della Rete internazionale delle pubbliche amministrazioni 1. Le amministrazioni di cui all'articolo 1, comma 1, del decreto legislativo 12 febbraio 1993, n. 39, che abbiano l'esigenza di connettivita' verso l'estero, sono tenute ad avvalersi dei servizi offerti dalla Rete internazionale delle pubbliche amministrazioni, interconnessa al SPC. 2. Le pubbliche amministrazioni di cui al comma 1, che dispongono di reti in ambito internazionale sono tenute a migrare nella Rete internazionale delle pubbliche amministrazioni entro il 15 marzo 2007, fatto salvo quanto previsto dall'articolo 75, commi 2 e 3. 3. Le amministrazioni non ricomprese tra quelle di cui all'articolo 1, comma 1, del decreto legislativo 12 febbraio 1993, n. 39, ivi incluse le autorita' amministrative indipendenti, possono aderire alla Rete internazionale delle pubbliche amministrazioni. Art. 86. Compiti e oneri del CNIPA 1. Il CNIPA cura la progettazione, la realizzazione, la gestione ed evoluzione della Rete internazionale delle pubbliche amministrazioni, previo espletamento di procedure concorsuali ad evidenza pubblica per la selezione dei fornitori e mediante la stipula di appositi contratti-quadro secondo modalita' analoghe a quelle di cui all'articolo 83. 2. Il CNIPA, al fine di favorire una rapida realizzazione del SPC, per un periodo almeno pari a due anni a decorrere dalla data di approvazione dei contratti-quadro di cui all'articolo 83, comma 1, sostiene i costi delle infrastrutture condivise, a valere sulle risorse gia' previste nel bilancio dello Stato. 3. Al termine del periodo di cui al comma 2, i costi relativi alle infrastrutture condivise sono a carico dei fornitori proporzionalmente agli importi dei contratti di fornitura, e una quota di tali costi e' a carico delle pubbliche amministrazioni relativamente ai servizi da esse utilizzati. I costi, i criteri e la relativa ripartizione tra le amministrazioni sono determinati annualmente con decreto del Presidente del Consiglio dei Ministri, su proposta della Commissione, previa intesa con la Conferenza unificata cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, salvaguardando eventuali intese locali finalizzate a favorire il pieno ingresso nel SPC dei piccoli Comuni nel rispetto di quanto previsto dal comma 5. 4. Il CNIPA sostiene tutti gli oneri derivanti dai collegamenti in ambito internazionale delle amministrazioni di cui all'articolo 85, comma 1, per i primi due anni di vigenza contrattuale, decorrenti dalla data di approvazione del contratto quadro di cui all'articolo 83; per gli anni successivi ogni onere e' a carico della singola amministrazione contraente proporzionalmente ai servizi acquisiti. 5. Le amministrazioni non ricomprese tra quelle di cui all'articolo 1, comma 1, del decreto legislativo 12 febbraio 1993, n. 39, che aderiscono alla Rete internazionale delle pubbliche amministrazioni, ai sensi dell'articolo 85, comma 3, ne sostengono gli oneri relativi ai servizi che utilizzano. Art. 87. Regolamenti 1. Ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, con uno o piu' decreti sulla proposta del Presidente del Consiglio dei Ministri o, per sua delega, del Ministro per l'innovazione e le tecnologie, di concerto con il Ministro per la funzione pubblica, d'intesa con la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, sono adottati regolamenti per l'organizzazione del SPC, per l'avvalimento dei consulenti di cui all'articolo 80, comma 7, e per la determinazione dei livelli minimi dei requisiti richiesti per l'iscrizione agli elenchi dei fornitori qualificati del SPC di cui all'articolo 82.».

## Art. 31. - Modifica del capo VIII del decreto legislativo 7 marzo 2005, n. 82

1. Nel decreto legislativo l'espressione «Capo VIII» e' sostituita dalla seguente: «Capo IX» e conseguentemente la numerazione degli articoli da 72 a 76 e' sostituita dalla numerazione progressiva da 88 a 92.

## Art. 32. - Modifica all'articolo 75 del decreto legislativo 7 marzo 2005, n. 82

1. Dopo il comma 3 dell'articolo 75 del decreto legislativo sono aggiunti i seguenti: «3-bis. L'articolo 15, comma 1, della legge 15 marzo 1997, n. 59, e' abrogato. 3-ter. Il decreto legislativo 28 febbraio 2005, n. 42, e' abrogato.».

